USE EstimateDemo;
GO

-- Create a table with a column that (normally) is filled with ascending values
CREATE TABLE dbo.AscOrders
   (OrderID int NOT NULL IDENTITY,
    OrderDate datetime NOT NULL,
    OtherData char(80) NOT NULL DEFAULT ('Other Data'),
    CONSTRAINT PK_AscOrders PRIMARY KEY(OrderID));
GO

-- Add ten thousand rows of data (all in last week of May 2014)
DECLARE @i int = 0;
WHILE @i < 10000
BEGIN;
    SET @i += 1;
    INSERT INTO dbo.AscOrders (OrderDate)
    VALUES (DATEADD(minute, @i, '20140524'));
END;
GO

-- Find all orders for June and later (this will create stats for OrderDate)
-- (Enable execution plan)
SELECT COUNT(*)
FROM   dbo.AscOrders
WHERE  OrderDate >= '20140601'
OPTION (RECOMPILE);

-- Check the statistics that were created
DBCC SHOW_STATISTICS ('dbo.AscOrders',
                      OrderDate);
GO



-- Or (to use a really ascending **key** column): all orders with ID > 9950
-- And it affects keys as well
SELECT COUNT(*)
FROM   dbo.AscOrders
WHERE  OrderID > 9950
OPTION (RECOMPILE);
GO



-- Add another two thousand rows (in June 2014)
-- (Disable execution plan)
DECLARE @i int = 0;
WHILE @i < 2000
BEGIN;
    SET @i += 1;
    INSERT INTO dbo.AscOrders (OrderDate)
    VALUES (DATEADD(minute, @i, '20140601'));
END;
GO

-- Statistics are not updated (threshold = 500 + 20% = 20500)
DBCC SHOW_STATISTICS ([dbo.AscOrders],
                      OrderDate);
GO

-- The estimate for these queries are now way off
-- (Enable execution plan)
SELECT COUNT(*)
FROM   dbo.AscOrders
WHERE  OrderDate >= '20140601'
OPTION (RECOMPILE);

SELECT COUNT(*)
FROM   dbo.AscOrders
WHERE  OrderID > 9950
OPTION (RECOMPILE);
GO
